@@ -5,6 +5,7 @@ import json
 from sdc_helpers.models.client import Client
 from sdc_helpers.redis_helper import RedisHelper
 import boto3
+from sdc_engine_helpers.sagemaker.utils import create_resource_name
 from sdc_engine_helpers import queue_utils
 from sdc_engine_helpers.sagemaker.sagemaker_query_helpers import \
     SagemakerEngineHelpers
@@ -189,10 +190,12 @@ class RecommendationsManager:
 
         item_codes = []
 
-        cache_key = self.query_helper.create_resource_name(
-            service=self.service.name,
-            group=self.item_code_identifier,
-            prefix=[self.engine, self.client.name]
+        cache_key = create_resource_name(
+            context='recommendation',
+            function=self.item_code_identifier,
+            additional_details=[
+                self.service.id, self.client.id, self.engine
+            ]
         )
 
         if from_cache:
@@ -208,22 +211,9 @@ class RecommendationsManager:
                 item_code = item_code.decode("utf-8")
 
             # check if item_id is none
-            if item_code is None:
-                # get item_id from database if none
-                key = item_ids[i]
-                item_code = self.query_helper.get_item_from_lookup(
-                    client_id=self.client.id,
-                    service_id=self.service.id,
-                    engine=self.engine,
-                    label=self.item_code_identifier,
-                    key=key
-                )
+            if item_code is not None:
 
-                if item_code is not None:
-                    # store in cache
-                    self.redis_helper.redis_hmset(hashkey=cache_key, dict_obj={key:item_code})
-
-            item_codes[i] = item_code
+                item_codes[i] = item_code
 
         return item_codes
 
@@ -244,10 +234,10 @@ class RecommendationsManager:
         """
         item_ids = []
 
-        cache_key = self.query_helper.create_resource_name(
-            service=self.service.name,
-            group=self.item_id_identifier,
-            prefix=[self.engine, self.client.name]
+        cache_key = create_resource_name(
+            context='recommendation',
+            function=self.item_id_identifier,
+            additional_details=[self.service.id, self.client.id, self.engine]
         )
 
         if from_cache:
@@ -263,22 +253,9 @@ class RecommendationsManager:
                 item_id = item_id.decode("utf-8")
 
             # check if item_id is none
-            if item_id is None:
-                # get item_id from database if none
-                key = item_codes[i]
-                item_id = self.query_helper.get_item_from_lookup(
-                    client_id=self.client.id,
-                    service_id=self.service.id,
-                    engine=self.engine,
-                    label=self.item_id_identifier,
-                    key=key
-                )
+            if item_id is not None:
 
-                if item_id is not None:
-                    # store in cache
-                    self.redis_helper.redis_hmset(hashkey=cache_key, dict_obj={key:item_id})
-
-            item_ids[i] = item_id
+                item_ids[i] = item_id
 
         return item_ids
 
